---
title: "Morality in a Determined World"
date: 2017-10-15T23:35:29Z
tags: ["free will","determinism","moral choice","ethics"]
topics: ["philosophy"]
image: img/morality-heads.jpg
draft: false
---

This essay will attempt an answer to the following question: If determinism is true, is morality an illusion? In other words, if we take the basic fact of causal necessity – the brute physical explanation that every effect has a cause – as a given, can we justify a belief in moral value and normative judgment in the narrow sense of “good” and “bad”? I will argue that there are good reasons to believe in the reality of both moral judgment and moral value in spite of causal necessity. Firstly, I will show that causal necessity does not entail what determinists insist of it. Secondly, I will argue that causal necessity leaves us no choice but to accept the responsibility of making moral choices, as members of the human community. Lastly, I will argue that the status of morality as a real phenomenon need not rest on naïve notions of ontological independence from the human mind.

The determinist insists on a universe in which all effects are perfectly determined from prior causes all the way back to the so-called “Big Bang”. He argues that we could, in principle, explain all effects in terms of their prior causes, if we only had the means to acquire enough knowledge to do so. We know from quantum physics that this is not actually true. Quantum indeterminacy shows that predictions at the sub-atomic level are a probabilistic affair, at best. Though this is not enough to claim free will (because brute randomness is just as much a causal driver as a perfectly predictable mechanical universe), it does show that the traditional view of determinism is in need of some updating. What’s more, as Peter Tse[^1] has argued, neural activity – one level up from the sub-atomic – is not a purely ballistic process (i.e., like billiard balls bouncing around). Rather, according to Tse, neurons behave more like a “store and forward” messaging system, in which groups of “epi-connected” neurons assemble into temporary networks, that collect and release electrochemical energy by way of criterial threshold triggers that may be pattern-specific. These criterial triggers can effect future neural states, and the arrangement of subsequent “epi-connected” networks, which makes their behavior indeterminate, but of a non-random nature. These two phenomenon (random quantum indeterminacy, and non-random neural indeterminacy) together, function as a necessary first condition for genuine choice-making activity in the brain. But none of this need be true, necessarily, to refute the main complaint of the determinist. Namely, that moral “responsibility” could not rest with the individual making the apparent choice, because the individual is not the “ultimate” cause of his behavior and because he’s not really making a choice. To begin with, there is no reason I know of, why responsibility can only rest on a causal terminus. So what if I’m not the ultimate cause of my choice? In fact, I can’t really think of any choice I’ve ever made, in which I was the originating source of the choice. By this reasoning, the Big Bang itself would become the ultimate scape goat. So, that objection seems spurious to me. On the question of whether I’m actually making a choice or not, this objection seems to beg the question it is trying to prove. Perhaps I am making an actual choice. The traditional determinist has yet to prove otherwise, and as I have shown, there is good evidence to suggest that he may be operating on obsolete information.

But Dr. Tse’s work is, at the moment, only an untested theory. So, prudence and charity suggests that taking the determinist’s position as a given might be the safer bet. If the human mind is indeed determined in a ballistic sense, just as the rest of physical matter in the universe, and the barrier to making all human activity predictable is not one of principle, but of mere technological prowess, would this mean our impulse to moral judgment is illusory, or that maintaining moral position is indulging in a fiction? When I consider what it means to be a human being, I think not. While we are animals that have evolved just like all others have, we are yet primates of a very peculiar variety. We are creatures driven by a psychology that was chiseled out of environmental pressures that determined a set of genetic traits that were necessary for the reproductive success of primates in that early environment. That process has, as Frans de Waal[^2] has outlined, equipped us with a highly sophisticated cognitive and emotional apparatus (whether as primary or secondary traits is somewhat irrelevant at the moment), that enabled such things as gratification deferment, long-term planning, cost/benefit calculation, and comparative judgment. These traits have enabled highly sophisticated social interactions and complex social structures in which genetic relatedness, reciprocal altruism, sympathetic resentment, emotional contagion, empathy, and a robust theory of mind, have all culminated in a “moral sense” that is both self- and other-directed. This collection of “moral sentiments” is necessarily normative, because each of us, as a specimen of the human primate species, requires a means by which we can determine our “fit” in the social order so as to budget our resource acquisition and mating opportunities. The ways in which this evaluative process expresses itself and the individual, and subsequently the group, is going to vary broadly with climatic conditions and population (and is a topic for another time), but in general, when attitudes arising from these evaluations are systematized into moral “codes”, or political philosophies, this we want to call “morality”. What this means, is that morality is not illusory, but it is also not what we typically think it is. It is a psycho-biological phenomenon that consists in a process of continuous negotiation, competition, and collaboration, that regulate the behavior of the species over time, and in response to environmental pressures. There is a further consequence: as a member of this species, I have no choice but to participate in this process. My brain is constructed to perform these evaluative judgments, and to seek commerce with (and protection within) my in- groups. The common question, “why should I be moral?”, is thus answerable by saying that you already are, necessarily. The only thing that remains is, what are you going to do about it?

It might be objected at this point, that these evaluations are purely mythical because no such qualities as “good” and “bad” can be identified in the actions of an individual in the way that angular momentum or velocity can be. Or, it may be contested that because such things as moral “value” are negotiated, they are a mere “social construct”, and therefore ought not be taken seriously. Both objections, it seems to me, come down to an unreasonably reductive insistence on a narrow conception of “existence” as nothing more than physical matter and energy. Even the most materialist of Marxist economists would be willing to acknowledge the “real” store of value present in a ten pound note. As noted above, such things as the capacity for long-term planning, gratification deferment, and cost-benefit calculation (as well as language, and a sense of reciprocity and expectation), enable the creation of real symbols of evaluative judgment – simple commodities upon which we psychologically project a certain qualitative or quantitative meaning. While it is true that different groups of people have used different commodities and have imbued those tokens with different degrees of importance and different kinds of meaning, they have all nonetheless engaged in the creation and representation of real value. If we are willing to accept this as an example of value in real form, why would we not accept the same for morality? Why would we take the collective store of moral value to be less “real”, than the collective store of economic value? Seems to me, without a principle for making such a choice, I’d only be engaging in an act of caprice, and denying my own nature in the process.

The arguments above cannot help us explain what kinds of things we need to evaluate, what means of evaluation we ought to engage in, how much importance the evaluations deserve, or even which evaluations are appropriate in any given situation. Rather, all I have tried to show, is that accepting a deterministic view of reality hardly excuses us from the fact of morality, as a human phenomenon. Far from excusing us from moral choice because mere illusion, a deterministic understanding, when coupled with the science of evolution and psychology, makes morality an inescapable inevitability for us (or, at least, a biological fact of life – even if accidental). What’s more, in trying to characterize morality as an “illusion” because of causal necessity or biological determination, we’re doing nothing less than trying to deny the responsibility with which nature itself has tasked us. For those of us who choose to take up this burden, the challenge is precisely this: to explain what it really is, and to show how we can best make use of it.

```[Imported from exitingthecave.com on 30 November 2021]```

[^1]: Peter Tse, The Neural Basis of Free Will, MIT Press, Massachusetts, 2013 
[^2]: Frans de Waal, Primates and Philosophers, Princeton University Press, Princeton, NJ, 2006 
